PlanExecuteAgent

Struct PlanExecuteAgent 

pub struct PlanExecuteAgent { /* private fields */ }
Plan-Execute Agent: plans first, executes step by step, and replans on failure.

Supports any LLM provider that implements BaseChatModel.

Implementations

Source

impl PlanExecuteAgent

pub fn new<L>(llm: L, tools: Vec<Arc<dyn BaseTool>>) -> Self
where L: BaseChatModel + Send + Sync + 'static, L::Error: Into<ProviderError>,

Creates a new Plan-Execute Agent

Parameters
  • llm - LLM client (any type implementing BaseChatModel)
  • tools - available tools
Backward compatibility

Legacy code PlanExecuteAgent::new(openai_chat, tools) still works.

pub fn from_arc( llm: Arc<dyn BaseChatModel<Error = ProviderError> + Send + Sync>, tools: Vec<Arc<dyn BaseTool>>, ) -> Self

Creates an agent from an already-wrapped Arc<dyn BaseChatModel>

pub fn with_max_replans(self, n: usize) -> Self

Sets the maximum number of replans.

pub fn with_agent_factory( self, factory: Arc<dyn Fn() -> Arc<dyn BaseAgent> + Send + Sync>, ) -> Self

Custom factory for the per-step execution agent (P1-2).

The BaseAgent returned by the factory is used for each execute_step of the PlanExecute. Defaults to FunctionCallingAgent. Useful for injecting ReAct / Streaming / custom agents as the execution agent.

pub async fn run(&self, objective: &str) -> Result<String, PlanExecuteError>

Runs the full task: plan -> execute each step -> replan on failure -> summarize