#[non_exhaustive]pub enum CompactionStrategy {
SlidingWindow {
keep_recent_turns: usize,
},
TokenBudget {
max_tokens: usize,
keep_recent_turns: usize,
},
}Expand description
How to compact. All strategies drop the oldest turns and keep at least
CompactionConfig::min_recent_turns recent ones.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
SlidingWindow
Keep only the most recent keep_recent_turns steps (sliding window).
TokenBudget
Drop the oldest steps until the estimated token footprint is within
max_tokens, but never below keep_recent_turns steps.