pub struct PlanExecuteAgent { /* private fields */ }Expand description
Plan-Execute Agent: plans first, executes step by step, and replans on failure.
Supports any LLM provider that implements BaseChatModel.
Implementations
Sourceimpl PlanExecuteAgent
impl PlanExecuteAgent
Sourcepub fn from_arc(
llm: Arc<dyn BaseChatModel<Error = ProviderError> + Send + Sync>,
tools: Vec<Arc<dyn BaseTool>>,
) -> Self
pub fn from_arc( llm: Arc<dyn BaseChatModel<Error = ProviderError> + Send + Sync>, tools: Vec<Arc<dyn BaseTool>>, ) -> Self
Creates an agent from an already-wrapped Arc<dyn BaseChatModel>
Sourcepub fn with_max_replans(self, n: usize) -> Self
pub fn with_max_replans(self, n: usize) -> Self
Sets the maximum number of replans.
Sourcepub fn with_agent_factory(
self,
factory: Arc<dyn Fn() -> Arc<dyn BaseAgent> + Send + Sync>,
) -> Self
pub fn with_agent_factory( self, factory: Arc<dyn Fn() -> Arc<dyn BaseAgent> + Send + Sync>, ) -> Self
Custom factory for the per-step execution agent (P1-2).
The BaseAgent returned by the factory is used for each execute_step
of the PlanExecute. Defaults to FunctionCallingAgent. Useful for
injecting ReAct / Streaming / custom agents as the execution agent.